Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(74)

Unified Diff: chromeos/geolocation/simple_geolocation_provider.h

Issue 1819173002: SimpleGeolocation should support sending WiFi AP data. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Update after review. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/chromeos.gyp ('k') | chromeos/geolocation/simple_geolocation_provider.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/geolocation/simple_geolocation_provider.h
diff --git a/chromeos/geolocation/simple_geolocation_provider.h b/chromeos/geolocation/simple_geolocation_provider.h
index 6ba20dc21cd0a70a6cb3ca27e0170ee9651c45f1..245dc27111ddcb69bcbfc14d5b55a4d8df15d539 100644
--- a/chromeos/geolocation/simple_geolocation_provider.h
+++ b/chromeos/geolocation/simple_geolocation_provider.h
@@ -33,9 +33,11 @@ class CHROMEOS_EXPORT SimpleGeolocationProvider {
const GURL& url);
virtual ~SimpleGeolocationProvider();
// Initiates new request (See SimpleGeolocationRequest for parameters
// description.)
void RequestGeolocation(base::TimeDelta timeout,
+ bool send_wifi_access_points,
SimpleGeolocationRequest::ResponseCallback callback);
// Returns default geolocation service URL.
« no previous file with comments | « chromeos/chromeos.gyp ('k') | chromeos/geolocation/simple_geolocation_provider.cc » ('j') | no next file with comments »
@@ -33,9 +33,11 @@ class CHROMEOS_EXPORT SimpleGeolocationProvider {
const GURL& url);
virtual ~SimpleGeolocationProvider();
- // Initiates new request (See SimpleGeolocationRequest for parameters
- // description.)
+ // Initiates new request. If |send_wifi_access_points|, WiFi AP information
+ // will be added to the request. See SimpleGeolocationRequest for the
+ // description of the other parameters.
void RequestGeolocation(base::TimeDelta timeout,

Powered by Google App Engine
This is Rietveld 408576698